@@ -10,7 +10,7 @@
 ########################################################################
 
 package Object::Trampoline;
-
+use v5.12;
 use strict;
 
 use Carp;
@@ -19,7 +19,8 @@ use Carp;
 # package variables
 ########################################################################
 
-our $VERSION    = "1.26";
+our $VERSION    = "1.28";
+$VERSION        = eval $VERSION;
 
 # minimal sanity check for valid class name, used in both
 # O::T and O::T::U.
